@@ -61,7 +61,7 @@ class SimpleTopic:
         logger.debug(f'topic: {topic_name}, ack qid: {qid}')
         return result
 
-    def info(self, ):
+    def info(self):
         desp = {name: f'queue size = {q.queue_size()}, dict size = {q.dict_size()}' for name, q in self._topics.items()}
         return desp
 
